---@param name string
---@param speed number
---@return Fielder
function newFielder(name, speed)
    return {
        name = name,
        speed = speed,
    }
end

-- selene: allow(unscoped_variables)
Field = {
    fielders = {
        first = newFielder("First", 40),
        second = newFielder("Second", 40),
        shortstop = newFielder("Shortstop", 40),
        third = newFielder("Third", 40),
        pitcher = newFielder("Pitcher", 30),
        catcher = newFielder("Catcher", 35),
        left = newFielder("Left", 40),
        center = newFielder("C.Center", 40),
        right = newFielder("Right", 40),
    },
}

--- Actually only benches the infield, because outfielders are far away!
---@param position XYPair
function Field.benchTo(self, position)
    self.fielders.first.target = position
    self.fielders.second.target = position
    self.fielders.shortstop.target = position
    self.fielders.third.target = position
    self.fielders.pitcher.target = position
    self.fielders.catcher.target = position
end

--- Resets the target positions of all fielders to their defaults (at their field positions).
---@param fromOffTheField XYPair | nil If provided, also sets all runners' current position to one centralized location.
function Field.resetFielderPositions(self, fromOffTheField)
    if fromOffTheField then
        for _, fielder in pairs(self.fielders) do
            fielder.x = fromOffTheField.x
            fielder.y = fromOffTheField.y
        end
    end

    self.fielders.first.target = utils.xy(C.Screen.W - 65, C.Screen.H * 0.48)
    self.fielders.second.target = utils.xy(C.Screen.W * 0.70, C.Screen.H * 0.30)
    self.fielders.shortstop.target = utils.xy(C.Screen.W * 0.30, C.Screen.H * 0.30)
    self.fielders.third.target = utils.xy(C.Screen.W * 0.1, C.Screen.H * 0.48)
    self.fielders.pitcher.target = utils.xy(C.PitcherStartPos.x, C.PitcherStartPos.y)
    self.fielders.catcher.target = utils.xy(C.Screen.W * 0.475, C.Screen.H * 0.92)
    self.fielders.left.target = utils.xy(C.Screen.W * -1, C.Screen.H * -0.2)
    self.fielders.center.target = utils.xy(C.Center.x, C.Screen.H * -0.4)
    self.fielders.right.target = utils.xy(C.Screen.W * 2, self.fielders.left.target.y)
end
